==> screem_0.10.2.orig.tar.gz: screem-0.10.2/src/screemmarshal.h <==

#ifndef __screem_marshal_MARSHAL_H__
#define __screem_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT,INT (./screemmarshal.list:25) */
extern void screem_marshal_VOID__INT_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:STRING,POINTER (./screemmarshal.list:26) */
extern void screem_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:VOID (./screemmarshal.list:27) */
#define screem_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:INT (./screemmarshal.list:28) */
#define screem_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:UINT,UINT (./screemmarshal.list:29) */
extern void screem_marshal_VOID__UINT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:UINT,POINTER,POINTER,POINTER,POINTER,BOOLEAN (./screemmarshal.list:30) */
extern void screem_marshal_VOID__UINT_POINTER_POINTER_POINTER_POINTER_BOOLEAN (GClosure     *closure,
                                                                               GValue       *return_value,
                                                                               guint         n_param_values,
                                                                               const GValue *param_values,
                                                                               gpointer      invocation_hint,
                                                                               gpointer      marshal_data);

/* VOID:STRING,STRING,POINTER (./screemmarshal.list:31) */
extern void screem_marshal_VOID__STRING_STRING_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:OBJECT (./screemmarshal.list:32) */
#define screem_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,UINT,UINT (./screemmarshal.list:33) */
extern void screem_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:STRING,STRING,UINT (./screemmarshal.list:34) */
extern void screem_marshal_VOID__STRING_STRING_UINT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:UINT,UINT,STRING,STRING,STRING,STRING (./screemmarshal.list:35) */
extern void screem_marshal_VOID__UINT_UINT_STRING_STRING_STRING_STRING (GClosure     *closure,
                                                                        GValue       *return_value,
                                                                        guint         n_param_values,
                                                                        const GValue *param_values,
                                                                        gpointer      invocation_hint,
                                                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __screem_marshal_MARSHAL_H__ */

==> screem_0.12.1.orig.tar.gz: screem-0.12.1/src/screemmarshal.h <==

#ifndef __screem_marshal_MARSHAL_H__
#define __screem_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT,INT (./screemmarshal.list:25) */
extern void screem_marshal_VOID__INT_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:STRING,POINTER (./screemmarshal.list:26) */
extern void screem_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:VOID (./screemmarshal.list:27) */
#define screem_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:INT (./screemmarshal.list:28) */
#define screem_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:UINT,UINT (./screemmarshal.list:29) */
extern void screem_marshal_VOID__UINT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:UINT,POINTER,POINTER,POINTER,POINTER,BOOLEAN (./screemmarshal.list:30) */
extern void screem_marshal_VOID__UINT_POINTER_POINTER_POINTER_POINTER_BOOLEAN (GClosure     *closure,
                                                                               GValue       *return_value,
                                                                               guint         n_param_values,
                                                                               const GValue *param_values,
                                                                               gpointer      invocation_hint,
                                                                               gpointer      marshal_data);

/* VOID:STRING,STRING,POINTER (./screemmarshal.list:31) */
extern void screem_marshal_VOID__STRING_STRING_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

/* VOID:OBJECT (./screemmarshal.list:32) */
#define screem_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,OBJECT (./screemmarshal.list:33) */
extern void screem_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:OBJECT,UINT,UINT (./screemmarshal.list:34) */
extern void screem_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:STRING,STRING,UINT (./screemmarshal.list:35) */
extern void screem_marshal_VOID__STRING_STRING_UINT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:UINT,UINT,STRING,STRING,STRING,STRING (./screemmarshal.list:36) */
extern void screem_marshal_VOID__UINT_UINT_STRING_STRING_STRING_STRING (GClosure     *closure,
                                                                        GValue       *return_value,
                                                                        guint         n_param_values,
                                                                        const GValue *param_values,
                                                                        gpointer      invocation_hint,
                                                                        gpointer      marshal_data);

/* VOID:STRING (./screemmarshal.list:37) */
#define screem_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:BOOLEAN (./screemmarshal.list:38) */
#define screem_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:UINT (./screemmarshal.list:39) */
#define screem_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

G_END_DECLS

#endif /* __screem_marshal_MARSHAL_H__ */
